# UploadFile

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**token** | **str** | A token referencing a specific file upload that can be used across requests | [optional] 
**description** | **str** | The file description | [optional] 
**columns** | [**list[DatasetColumn]**](DatasetColumn.md) | A list of dataset column metadata | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


